#########Generate simulated functional data object
GenDataK = function(sample_num,sampling_points,
                    dtd,di,ddi,psi,dpsi,
                    eta,deta,center=0,
                    delta,dflag,type="efsft")
{
  ###	Here we set the samples sizes for both samples.
  ###	N is the size of the K sample
  
  ###	Here we generate the simulated error terms, 'e'.  Each column of 'e'
  ###	represents an error funtion.
  ###	The variable 'sampling_points' determines the number of points
  ###	at which the error term will be defined.  The error term will be
  ### 	defined at one more place than the number 'sampling_points.'  Thus
  ###	if 'sampling_points' is equal to 100, then the error term will be
  ###	defined at 101 places.
  
  ###	Each error term will be either Brownian motion or a Brownian Bridge.
  ###	If sample1_bridge==true, then sample 1 error terms will be bridges.
  ###	Otherwise sample 1 error terms will be brownian motions.
  ###	A similar statement holds for sample 2.
  #type = efsft: shift of eigen functions
  #=evsft: shift of igenvalues
  #=mul: multiply
  
  e <- list();
  k <- length(sample_num);#group number
  p <- dim(psi)[1];
  psisft <- psi;
  disft <- di;
  etasft <- eta;
  mulsft <- 1;
  for (i in 1:k)
  {
    ni <- sample_num[i];
    e[[i]] <- fdata(ni,dtd,disft,psisft,dflag);
    #add mean;
    e[[i]] <- e[[i]]+matrix(etasft[,i],p,ni);
    if(type=="efsft")
    {
      psisft <- psisft+delta*dpsi;#psisft <- psi+delta*dpsi;#wrong!
    }else if(type=="evsft"){
      disft <- disft+delta*ddi;
    }else if(type=="mul"){
      e[[i]] <- e[[i]]*mulsft;
      mulsft <- mulsft + delta;
    }else if(type=="msft"){
      etasft <- etasft + delta*deta;
    }
    
    if(center==1)
    {
      e[[i]] <- e[[i]] - matrix(rowMeans(e[[i]]),p,ni);
    }
    
  }
  return(e);
}